Learn R Programming

infiltrodiscR (version 0.0.5)

infiltration: Cumulative infiltration and sqrt of time Using time and volume from field spreadsheets, the Cumulative infiltration and sqrt of time are calculated

Description

Cumulative infiltration and sqrt of time Using time and volume from field spreadsheets, the Cumulative infiltration and sqrt of time are calculated

Usage

infiltration(dataset, col_name)

Value

A tibble giving three new columns: sqrt_time, volume_infiltrated and infiltration

Arguments

dataset

A tibble or data.frame including time and volume

col_name

vars including time and volume

Examples

Run this code
infiltration(data.frame(time = c(0, 30, 60, 90, 120, 150, 180, 210, 240, 270, 300,
0, 35, 65, 95, 125, 155, 185, 215, 245, 275, 305),
volume = c(95, 89, 86, 83, 80, 77, 74, 73, 71, 69, 67,
           83, 77, 64, 61, 58, 45, 42, 35, 29, 17, 15)))

Run the code above in your browser using DataLab