Learn R Programming

infiltrodiscR (version 0.0.5)

vg_par: Tabulated VG parameters Van Genuchten parameters and values of A, n and alpha for the Minidisk Infiltrometer (Decagon Devices, Inc., 2005). 12 soil texture classes and suction from 0.5 to 7 cm are tabulated

Description

Tabulated VG parameters Van Genuchten parameters and values of A, n and alpha for the Minidisk Infiltrometer (Decagon Devices, Inc., 2005). 12 soil texture classes and suction from 0.5 to 7 cm are tabulated

Usage

vg_par(dataset, col_name)

Value

A tibble giving three new columns: n_ho, alpha and A value

Arguments

dataset

A tibble or data.frame including suction and texture

col_name

vars including suction and texture

Examples

Run this code
vg_par(data.frame(suction = c("2cm", "3cm"), texture = c("sand", "clay")))

Run the code above in your browser using DataLab