vg_par: Tabulated VG parameters
Van Genuchten parameters and values of A, n and alpha for the Minidisk
Infiltrometer (Decagon Devices, Inc., 2005).
12 soil texture classes and suction from
0.5 to 7 cm are tabulated
Description
Tabulated VG parameters
Van Genuchten parameters and values of A, n and alpha for the Minidisk
Infiltrometer (Decagon Devices, Inc., 2005).
12 soil texture classes and suction from
0.5 to 7 cm are tabulated
Usage
vg_par(dataset, col_name)
Value
A tibble giving three new columns: n_ho,
alpha and A value
Arguments
dataset
A tibble or data.frame including suction and texture